import React from 'react';
import { defaultTransforms } from './transforms/defaultTransforms.js';
export class Generator {
    errorIfNoTransform;
    transforms;
    constructor(transforms = defaultTransforms, errorIfNoTransform = true) {
        this.errorIfNoTransform = errorIfNoTransform;
        this.transforms = new Map(transforms.map((transform) => [transform.name, transform]));
    }
    joinAdjacentStrings(children) {
        return children.reduce((acc, child) => {
            if (typeof child === 'string' && typeof acc[acc.length - 1] === 'string') {
                acc[acc.length - 1] += child;
            }
            else {
                acc.push(child);
            }
            return acc;
        }, []);
    }
    generateForNode(node, i) {
        switch (node.nodeType) {
            case 2 /* AstNodeType.LinebreakNode */: {
                return [i + 1, React.createElement("br", { key: i })];
            }
            case 1 /* AstNodeType.TextNode */: {
                return [i, node.str];
            }
            case 3 /* AstNodeType.TagNode */: {
                const tagName = node.tagName;
                const transform = this.transforms.get(tagName);
                if (!transform) {
                    if (this.errorIfNoTransform) {
                        throw new Error(`Unrecognized bbcode ${node.tagName}`);
                    }
                    else {
                        console.warn(`Unrecognized bbcode ${node.tagName}`);
                    }
                    return [i, node.ogEndTag];
                }
                const renderedChildren = node.children.map((child, j) => {
                    const [newI, renderedChild] = this.generateForNode(child, i);
                    i = newI;
                    return renderedChild;
                });
                const { component: Component } = transform;
                const renderedTag = React.createElement(Component, { tagNode: node, key: i }, this.joinAdjacentStrings(renderedChildren));
                if (renderedTag === false) {
                    return [i, node.ogStartTag + renderedChildren + node.ogEndTag];
                }
                return [i + 1, renderedTag];
            }
            default: {
                const renderedChildren = node.children.map((child, j) => {
                    const [newI, renderedChild] = this.generateForNode(child, i);
                    i = newI;
                    return renderedChild;
                });
                return [i + 1, this.joinAdjacentStrings(renderedChildren)];
            }
        }
    }
    generate(root) {
        return React.createElement(React.Fragment, null, this.generateForNode(root, 0)[1]);
    }
}
//# sourceMappingURL=Generator.js.map