import React from 'react';
import { getWidthHeightAttr } from '../utils/getWidthHeightAttr.js';
import { isOrderedList } from '../utils/isOrderedList.js';
import { parseMaybeRelativeUrl } from '../utils/parseMaybeRelativeUrl.js';
export const defaultTransforms = [
    {
        name: 'b',
        component({ children }) {
            return React.createElement("b", null, children);
        }
    },
    {
        name: 'i',
        component({ children }) {
            return React.createElement("i", null, children);
        }
    },
    {
        name: 'u',
        component({ children }) {
            return React.createElement("u", null, children);
        }
    },
    {
        name: 's',
        component({ children }) {
            return React.createElement("del", null, children);
        }
    },
    {
        name: 'style',
        component({ children, tagNode }) {
            const { size, color } = tagNode.getAttributesByName();
            let fontSize = size;
            if (size && /^\d+$/.test(size)) {
                fontSize = `${size}%;`; // When no units provided (i.e. just a number), then assume %
            }
            return React.createElement("span", { style: {
                    color,
                    fontSize,
                } }, children);
        }
    },
    {
        name: 'color',
        component({ children, tagNode }) {
            return React.createElement("span", { style: { color: tagNode.getTagImmediateAttrVal() } }, children);
        }
    },
    {
        name: 'hr',
        isStandalone: true,
        component() {
            return React.createElement("hr", null);
        }
    },
    {
        name: 'list',
        component({ tagNode, children }) {
            return isOrderedList(tagNode)
                ? React.createElement("ol", null, children)
                : React.createElement("ul", null, children);
        }
    },
    {
        name: '*',
        isLinebreakTerminated: true,
        component({ children }) {
            return React.createElement("li", null, children);
        }
    },
    {
        name: 'img',
        skipChildren: true,
        component({ tagNode }) {
            let src = tagNode.getTagImmediateText() || tagNode.attributes.find(a => a.key === 'src') || tagNode.getTagImmediateAttrVal();
            if (!src || typeof src !== 'string') {
                return false;
            }
            const { path } = parseMaybeRelativeUrl(src);
            if (!path) {
                return false;
            }
            const { width, height } = getWidthHeightAttr(tagNode);
            return React.createElement("img", { src: path, width: width, height: height });
        }
    },
    {
        name: 'url',
        component({ children, tagNode }) {
            const rawUrl = tagNode.getTagImmediateAttrVal() || tagNode.getTagImmediateText();
            if (!rawUrl || typeof rawUrl !== 'string') {
                return false;
            }
            const { path } = parseMaybeRelativeUrl(rawUrl);
            if (!path) {
                return false;
            }
            return React.createElement("a", { href: path }, children);
        }
    },
    {
        name: 'quote',
        component({ children, tagNode }) {
            const immediateAttribute = tagNode.getTagImmediateAttrVal();
            return React.createElement("blockquote", null,
                immediateAttribute && React.createElement("strong", null, immediateAttribute),
                children);
        }
    },
    {
        name: 'table',
        component({ children }) {
            return React.createElement("table", null, children);
        }
    },
    {
        name: 'tr',
        component({ children }) {
            return React.createElement("tr", null, children);
        }
    },
    {
        name: 'td',
        component({ children }) {
            return React.createElement("td", null, children);
        }
    },
    {
        name: 'code',
        component({ children }) {
            return React.createElement("code", null, children);
        }
    },
];
//# sourceMappingURL=defaultTransforms.js.map